""" ... """

import argparse

from secrets_manager.decrypt import decrypt
from secrets_manager.settings import (
    SM_KEYS_PATH,
    SM_KEYS_FILE
)


if __name__ == "__main__":
    """ ... """

    parser = argparse.ArgumentParser()

    parser.add_argument(
        "text",
        help='Text to decode and decrypt.'
    )
    parser.add_argument(
        "--keys-path",
        nargs='?',
        default=SM_KEYS_PATH,
        help='File path for save keys.'
    )
    parser.add_argument(
        "--keys-name",
        nargs='?',
        default=SM_KEYS_FILE,
        help='File name for save keys.'
    )
    
    args = parser.parse_args()

    decrypted_text = decrypt(
        args.text,
        keys_path=args.keys_path,
        keys_name=args.keys_name
    )
    
    print(f"The decrypted message is: {decrypted_text}")


""" ... """

import rsa

from base64 import b64decode

from .settings import (
    SM_KEYS_PATH,
    SM_KEYS_FILE,
    SM_SECRETS_PATH,
    SM_SECRETS_FILE_IN,
    SM_SECRETS_FILE_OUT
)


def decrypt(
    text: str,
    keys_path: str = SM_KEYS_PATH,
    keys_name: str = SM_KEYS_FILE,
) -> str:
    """ ... """
    
    with open(f'{keys_path}/private_{keys_name}.pem', 'r') as file:
      base64_decoded = b64decode(text.encode('ASCII'))
      private_key = rsa.PrivateKey.load_pkcs1(file.read().encode('utf8'))
      decrypted_text = rsa.decrypt(base64_decoded, private_key).decode('utf8')

      return decrypted_text


def decrypt_from_file(
    keys_path: str = SM_KEYS_PATH,
    keys_name: str = SM_KEYS_FILE,
    secrets_path: str = SM_SECRETS_PATH,
    secrets_file_input: str = SM_SECRETS_FILE_OUT,
    secrets_file_output: str = SM_SECRETS_FILE_IN
):
   """ ... """

   with open(f'{secrets_path}/{secrets_file_output}', "w") as output_file:
        with open(f'{secrets_path}/{secrets_file_input}', "r") as file:
            for line in file.readlines():
                key_value_pair= line.split('=', 1)
                decrypted_text = decrypt(
                    key_value_pair[1],
                    keys_path=keys_path,
                    keys_name=keys_name
                )
                output_file.write(
                    f"{key_value_pair[0]}={decrypted_text}"
                )


""" ... """

import argparse

from secrets_manager.generate_keys import generate_keys
from secrets_manager.settings import SM_KEYS_PATH, SM_KEYS_FILE


if __name__ == "__main__":
    """ ... """

    parser = argparse.ArgumentParser()
    
    parser.add_argument(
        "--keys-path",
        nargs='?',
        default=SM_KEYS_PATH,
        help='File path for save keys.'
    )
    parser.add_argument(
        "--keys-name",
        nargs='?',
        default=SM_KEYS_FILE,
        help='File name for save keys.'
    )
    parser.add_argument(
        "--number-bits",
        nargs='?',
        default=256,
        help='Number of bits to generate keys.'
    )
    
    args = parser.parse_args()

    generate_keys(
        keys_path=args.keys_path,
        keys_name=args.keys_name,
        nbits=args.number_bits
    )


""" ... """

import os


SM_KEYS_PATH = os.environ.get("SM_KEYS_PATH", ".")
SM_KEYS_FILE = os.environ.get("SM_KEYS_FILE", "key")
SM_SECRETS_PATH = os.environ.get("SM_SECRETS_PATH", ".")
SM_SECRETS_FILE_IN = os.environ.get("SM_SECRETS_FILE_IN", ".env")
SM_SECRETS_FILE_OUT = os.environ.get("SM_SECRETS_FILE_OUT", "secrets.txt")


""" ... """

import rsa

from .settings import SM_KEYS_FILE, SM_KEYS_PATH

FORMAT = 'PEM'


def generate_keys(
    keys_path: str = SM_KEYS_PATH,
    keys_name: str = SM_KEYS_FILE,
    nbits: int = 256
) -> None:
    """ ... """

    public_key, private_key = rsa.newkeys(nbits)

    with open(f'{keys_path}/public_{keys_name}.pem', 'w') as file:
        file.write(public_key.save_pkcs1(FORMAT).decode('utf8'))
    
    with open(f'{keys_path}/private_{keys_name}.pem', 'w') as file:
        file.write(private_key.save_pkcs1(FORMAT).decode('utf8'))


""" ... """

from setuptools import find_packages, setup

setup(
    name='asm-secrets-manager',
    version='1.0.1',
    description='Just another Secrets Manager',
    long_description="This library objective is to aim the variables and secrets management for our software applications on remote repositories on most safe way.",
    long_description_content_type="text/markdown",
    url="https://gitlab.com/albertosanmartinmartinez/secrets-manager", # https://albertosanmartinmartinez.es
    author='Alberto Sanmartín Martínez',
    author_email='albertosanmartinmartinez@gmail.com',
    license="GPL v3",
    packages=find_packages(),
    install_requires=[
      "rsa==4.9"
    ],
    test_require=[
      
    ],
    classifiers=[
      "Development Status :: 5 - Production/Stable",
      "Environment :: Console",
      "Intended Audience :: Developers",
      "License :: OSI Approved :: GNU General Public License (GPL)",
      "Natural Language :: English",
      "Operating System :: Unix",
      "Programming Language :: Python",
      "Programming Language :: Python :: 3",
      "Topic :: Software Development :: Libraries :: Python Modules",
    ]
)


""" ... """

import argparse

from secrets_manager.encrypt import encrypt_from_file
from secrets_manager.settings import (
    SM_KEYS_PATH,
    SM_KEYS_FILE,
    SM_SECRETS_FILE_IN,
    SM_SECRETS_FILE_OUT,
    SM_SECRETS_PATH
)


if __name__ == "__main__":
    """ ... """

    parser = argparse.ArgumentParser()
    
    parser.add_argument(
        "--keys-path",
        nargs='?',
        default=SM_KEYS_PATH,
        help='File path for save keys.'
    )
    parser.add_argument(
        "--keys-name",
        nargs='?',
        default=SM_KEYS_FILE,
        help='File name for save keys.'
    )
    parser.add_argument(
        "--secrets-path",
        nargs='?',
        default=SM_SECRETS_PATH,
        help='File path for secrets.'
    )
    parser.add_argument(
        "--secrets-input",
        nargs='?',
        default=SM_SECRETS_FILE_IN,
        help='File name for read secrets.'
    )
    parser.add_argument(
        "--secrets-output",
        nargs='?',
        default=SM_SECRETS_FILE_OUT,
        help='File name for write secrets.'
    )

    args = parser.parse_args()

    encrypt_from_file(
        keys_path=args.keys_path,
        keys_name=args.keys_name,
        secrets_path=args.secrets_path,
        secrets_file_input=args.secrets_input,
        secrets_file_output=args.secrets_output
    )